package com.install4j.api.windows;

import com.install4j.runtime.installer.platform.win32.FolderInfo;

/**
 * Enumeration class for the different special system folders in Microsoft Windows.

 * @author ej-technologies GmbH
 */
public enum SpecialFolder {
    /**
     * Identifies the file system directory used to physically store file objects on the desktop.
     * A typical path is {@code C:\Users\<i>user name</i>\Desktop}.
     */
    DESKTOP(FolderInfo.FOLDER_DESKTOP),

    /**
     * Identifies the file system directory containing Start menu items.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Start Menu}.
     */
    STARTMENU(FolderInfo.FOLDER_STARTMENU),

    /**
     * Identifies the file system directory that contains the user's program groups.
     * The groups are themselves file system directories.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Start Menu\Programs}.
     */
    PROGRAMS(FolderInfo.FOLDER_PROGRAMS),

    /**
     * Identifies the file system directory that corresponds to the user's Startup program group.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Start Menu\Programs\Startup}.
     */
    STARTUP(FolderInfo.FOLDER_STARTUP),

    /**
     * Identifies the file system directory that contains Send To menu items.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\SendTo}.
     */
    SENDTO(FolderInfo.FOLDER_SENDTO),

    /**
     * Identifies a virtual folder containing fonts.
     * A typical path is {@code C:\Windows\Fonts}.
     */
    FONTS(FolderInfo.FOLDER_FONTS),

    /**
     * Identifies the file system directory that serves as a common repository for application-specific data.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Roaming}.
     */
    APPDATA(FolderInfo.FOLDER_APPDATA),

    /**
     * Identifies the file system directory used to physically store a user's common repository of documents.
     * A typical path is {@code C:\Users\<i>user name</i>\Documents}.
     */
    DOCS(FolderInfo.FOLDER_DOCS),

    /**
     * Identifies the file system directory that serves as a common repository for document templates.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Templates}.
     */
    TEMPLATES(FolderInfo.FOLDER_TEMPLATES),

    /**
     * Identifies the file system directory that serves as a common repository for the user's favorite items.
     * A typical path is {@code C:\Users\<i>user name</i>\Favorites}.
     */
    FAVORITES(FolderInfo.FOLDER_FAVORITES),

    /**
     * Identifies the file system directory that serves as a data repository for local applications.
     * A typical path is {@code C:\Users\<i>user name</i>\AppData\Local}.
     */
    LOCAL_APPDATA(FolderInfo.FOLDER_LOCAL_APPDATA);

    private int intValue;

    SpecialFolder(int intValue) {
        this.intValue = intValue;
    }

    int getIntValue() {
        return intValue;
    }


}
